@@ -1,5 +1,5 @@
 package JSON::Path::Evaluator;
-$JSON::Path::Evaluator::VERSION = '0.420';
+$JSON::Path::Evaluator::VERSION = '0.430';
 use strict;
 use warnings;
 use 5.008;
@@ -126,12 +126,12 @@ sub evaluate {
 sub _reftable_walker {
     my ( $self, $json_object, $base_path ) = @_;
 
-    $base_path   ||= '$';
-    $json_object ||= $self->root;
+    $base_path   = defined $base_path   ? $base_path   : '$';
+    $json_object = defined $json_object ? $json_object : $self->root;
 
     my @entries = ( refaddr $json_object => $base_path );
 
-    if ( ref $json_object eq 'ARRAY' ) {
+    if ( _arraylike($json_object) ) {
         for ( 0 .. $#{$json_object} ) {
             my $path = sprintf q{%s['%d']}, $base_path, $_;
             if ( ref $json_object->[$_] ) {
@@ -142,7 +142,7 @@ sub _reftable_walker {
             }
         }
     }
-    else {
+    elsif ( _hashlike($json_object) ) {
         for my $index ( keys %{$json_object} ) {
             my $path = sprintf q{%s['%s']}, $base_path, $index;
             if ( ref $json_object->{$index} ) {
@@ -161,7 +161,7 @@ sub _evaluate {    # This assumes that the token stream is syntactically valid
 
     return unless ref $obj;
 
-    $token_stream ||= [];
+    $token_stream = defined $token_stream ? $token_stream : [];
 
     while ( defined( my $token = shift @{$token_stream} ) ) {
         next if $token eq $TOKEN_CURRENT;
@@ -315,7 +315,10 @@ sub _get {
 
 sub _indices {
     my $object = shift;
-    return _hashlike($object) ? keys %{$object} : ( 0 .. $#{$object} );
+    return
+          _hashlike($object)  ? keys %{$object}
+        : _arraylike($object) ? ( 0 .. $#{$object} )
+        : ();
 }
 
 sub _hashlike {
@@ -486,7 +489,7 @@ sub _process_pseudo_js {
     if ( _hashlike($object) ) {
         @lhs = map { $self->_evaluate( $_, [@token_stream] ) } values %{$object};
     }
-    else {
+    elsif ( _arraylike($object) ) {
         for my $value ( @{$object} ) {
             my ($got) = $self->_evaluate( $value, [@token_stream] );
             push @lhs, $got;
@@ -643,7 +646,7 @@ JSON::Path::Evaluator - A module that recursively evaluates JSONPath expressions
 
 =head1 VERSION
 
-version 0.420
+version 0.430
 
 =head1 SYNOPSIS
 
@@ -907,11 +910,11 @@ instead.
 
 =head1 AUTHOR
 
-Kit Peters <kit.peters@broadbean.com>
+Kit Peters <popefelix@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Kit Peters.
+This software is copyright (c) 2021 by Kit Peters.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
