@@ -1,5 +1,5 @@
 package JSON::Path::Tokenizer;
-$JSON::Path::Tokenizer::VERSION = '0.420';
+$JSON::Path::Tokenizer::VERSION = '0.430';
 use strict;
 use warnings;
 use 5.008;
@@ -125,15 +125,15 @@ JSON::Path::Tokenizer - Helper class for JSON::Path::Evaluator. Do not call dire
 
 =head1 VERSION
 
-version 0.420
+version 0.430
 
 =head1 AUTHOR
 
-Kit Peters <kit.peters@broadbean.com>
+Kit Peters <popefelix@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Kit Peters.
+This software is copyright (c) 2021 by Kit Peters.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
